from ase import Atoms
from ase.build import molecule, add_adsorbate
from ase.calculators.vasp import Vasp
from ase.optimize import LBFGS
from ase.io import read
import numpy as np
from ase.io.trajectory import Trajectory
from ase.vibrations import Vibrations
from ase.visualize import view
from ase.thermochemistry import IdealGasThermo

surface=read('POSCAR')
surf=surface.copy()
view(surf)
print('setting up vasp calculation')
#vasp parameters
params = {'Zr': {'L': 2, 'U': 4.0, 'J': 0.0}}
print('the surface is created')
vasp_settings = {'xc': 'PBE',        #Functional to use
                 'istart': 0,        #Wavecar
                 'ivdw': 12,         #DispersionD3
                 'kpts': (3,3,1), #K Point mesh
                 'encut': 400.,      #Energy cutoff
                 'ismear': 0,        #Gaussian smearing
                 'sigma': 0.2,       #Width of smearing in eV
                 'ediff': 1e-6,      #Global break condition for the electronic selfconsistency loop
                 'prec': 'normal',   #Precision. Sets various other parameters
                 'lcharg': False,    #Whether LCHARG is written
                 'lwave': False,     #Whether LWAVE is written
                 'nelmin': 4,        #Minimum number of electronic selfconsistency steps
                 'nelmdl': -6,        #Number of non-selfconsistent steps at the beginning
                 'npar': 5,          #Number of bands that are treated in parallel
                 'algo': 'fast',     #Electronic minimization algorithm
                 'lreal': 'auto',    #Determines whether projection operators are evaluated in real or reciprocal space
                 'ldau': True,        #LDA+U on
                 'ldau_luj': params,   #parameters
                 'lasph': True,        #include non-spherical contributions to gradient
                 'ispin': 1}         #Whether to use spin or non-spin polarized calculations
calc = Vasp(**vasp_settings)
surf.set_calculator(calc)
print('Energy = {} eV'.format(surf.get_potential_energy()))
print('Atomic coordinates')
print('vibrational analysis')
vib = Vibrations(surf,indices=[94,176,78,128,129]+list(range(194,208)),delta=0.015)
vib.run()
vib.summary()
vib_energies = vib.get_energies()
vib.write_mode()#Trajectory File
print(vib_energies)
